@@ -114,6 +114,7 @@ e_editable_theme_set(Evas_Object *editable, const char *category, const char *gr
    char *obj_group;
    const char *data;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    if ((!category) || (!group)) return;
@@ -165,6 +166,7 @@ e_editable_password_set(Evas_Object *editable, int password_mode)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    if (sd->password_mode == password_mode) return;
@@ -185,6 +187,7 @@ e_editable_password_get(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
    return sd->password_mode;
@@ -201,6 +204,7 @@ e_editable_text_set(Evas_Object *editable, const char *text)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
 
@@ -237,6 +241,7 @@ e_editable_text_get(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(NULL);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return NULL;
    return sd->text;
@@ -258,6 +263,7 @@ e_editable_text_range_get(Evas_Object *editable, int start, int end)
    char *range;
    int start_id = 0, end_id = 0, i;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(NULL);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return NULL;
 
@@ -293,6 +299,7 @@ e_editable_text_length_get(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
    return sd->unicode_length;
@@ -312,6 +319,7 @@ e_editable_insert(Evas_Object *editable, int pos, const char *text)
    E_Editable_Smart_Data *sd;
    int unicode_length;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
 
@@ -342,6 +350,7 @@ e_editable_delete(Evas_Object *editable, int start, int end)
    E_Editable_Smart_Data *sd;
    int unicode_length;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
 
@@ -373,11 +382,12 @@ e_editable_cursor_pos_set(Evas_Object *editable, int pos)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
 
    pos = E_CLAMP(pos, 0, sd->unicode_length);
-   if ((sd->cursor_pos == pos)) return;
+   if (sd->cursor_pos == pos) return;
 
    sd->cursor_pos = pos;
    _e_editable_cursor_update(editable);
@@ -394,11 +404,33 @@ e_editable_cursor_pos_get(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
    return sd->cursor_pos;
 }
 
+/**
+ * Gets the geometry of the cursor of the editable object
+ *
+ * @param editable an editable object
+ * @param cx the x of the cursor
+ * @param cy the y of the cursor
+ * @param cw the width of the cursor
+ * @param ch the height of the cursor
+ */
+EAPI void
+e_editable_cursor_geometry_get(Evas_Object *editable, Evas_Coord *cx, Evas_Coord *cy, Evas_Coord *cw, Evas_Coord *ch)
+{
+   E_Editable_Smart_Data *sd;
+
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
+   if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
+     return;
+
+   evas_object_geometry_get(sd->cursor_object, cx, cy, cw, ch);
+}
+
 /**
  * Moves the cursor to the start of the editable object
  *
@@ -407,6 +439,7 @@ e_editable_cursor_pos_get(Evas_Object *editable)
 EAPI void
 e_editable_cursor_move_to_start(Evas_Object *editable)
 {
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if (!editable)
      return;
    e_editable_cursor_pos_set(editable, 0);
@@ -422,6 +455,7 @@ e_editable_cursor_move_to_end(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_cursor_pos_set(editable, sd->unicode_length);
@@ -437,6 +471,7 @@ e_editable_cursor_move_left(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_cursor_pos_set(editable, sd->cursor_pos - 1);
@@ -452,6 +487,7 @@ e_editable_cursor_move_right(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_cursor_pos_set(editable, sd->cursor_pos + 1);
@@ -467,6 +503,7 @@ e_editable_cursor_show(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    if (sd->cursor_visible) return;
@@ -489,6 +526,7 @@ e_editable_cursor_hide(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    if (!sd->cursor_visible) return;
@@ -508,6 +546,7 @@ e_editable_selection_pos_set(Evas_Object *editable, int pos)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
 
@@ -529,6 +568,7 @@ e_editable_selection_pos_get(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
    return sd->selection_pos;
@@ -542,6 +582,7 @@ e_editable_selection_pos_get(Evas_Object *editable)
 EAPI void
 e_editable_selection_move_to_start(Evas_Object *editable)
 {
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if (!editable)
      return;
    e_editable_selection_pos_set(editable, 0);
@@ -557,6 +598,7 @@ e_editable_selection_move_to_end(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_selection_pos_set(editable, sd->unicode_length);
@@ -572,6 +614,7 @@ e_editable_selection_move_left(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_selection_pos_set(editable, sd->selection_pos - 1);
@@ -587,6 +630,7 @@ e_editable_selection_move_right(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_selection_pos_set(editable, sd->selection_pos + 1);
@@ -602,7 +646,7 @@ e_editable_selection_move_right(Evas_Object *editable)
 EAPI void
 e_editable_select_all(Evas_Object *editable)
 {
-   if (!editable) return;
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    e_editable_selection_move_to_start(editable);
    e_editable_cursor_move_to_end(editable);
 }
@@ -618,6 +662,7 @@ e_editable_unselect_all(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    e_editable_selection_pos_set(editable, sd->cursor_pos);
@@ -627,21 +672,22 @@ e_editable_unselect_all(Evas_Object *editable)
  * Selects the word at the provided character index
  */
 EAPI void
-e_editable_select_word(Evas_Object *editable, int index)
+e_editable_select_word(Evas_Object *editable, int idx)
 {
    E_Editable_Smart_Data *sd;
    int spos = 0, epos = -1, i = 0, pos = 0;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
-   if ((index < 0) || (index >= sd->unicode_length)) return;
+   if ((idx < 0) || (idx >= sd->unicode_length)) return;
 
    while (i < sd->char_length)
      {
 	if (sd->text[i] == ' ')
 	  {
-	     if (pos < index) spos = pos + 1;
-	     else if (pos > index)
+	     if (pos < idx) spos = pos + 1;
+	     else if (pos > idx)
 	       {
 		  epos = pos;
 		  break;
@@ -665,6 +711,7 @@ e_editable_selection_show(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    if (sd->selection_visible) return;
@@ -684,6 +731,7 @@ e_editable_selection_hide(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
    if (!sd->selection_visible) return;
@@ -710,9 +758,10 @@ e_editable_pos_get_from_coords(Evas_Object *editable, Evas_Coord x, Evas_Coord y
    Evas_Coord tx, ty, tw, th;
    Evas_Coord cx, cw;
    Evas_Coord canvas_x, canvas_y;
-   int index, pos, i, j;
+   int idx, pos, i, j;
    const char *text;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERR(0);
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
    if (!(text_obj = edje_object_part_object_get(sd->text_object, "e.text.text")))
@@ -729,18 +778,18 @@ e_editable_pos_get_from_coords(Evas_Object *editable, Evas_Coord x, Evas_Coord y
      pos = sd->unicode_length;
    else
      {
-        index = evas_object_text_char_coords_get(text_obj,
+        idx = evas_object_text_char_coords_get(text_obj,
                                                  canvas_x - tx, canvas_y - ty,
                                                  &cx, NULL, &cw, NULL);
         text = evas_object_text_text_get(text_obj);
-        if ((index >= 0) && (text))
+        if ((idx >= 0) && (text))
           {
-             if ((canvas_x - tx) > (cx + (cw / 2))) index++;
+             if ((canvas_x - tx) > (cx + (cw / 2))) idx++;
 
              i = 0;
              j = -1;
              pos = 0;
-             while ((i < index) && (j != i))
+             while ((i < idx) && (j != i))
                {
                   pos++;
                   j = i;
@@ -777,6 +826,7 @@ e_editable_char_size_get(Evas_Object *editable, int *w, int *h)
 
    if (w) *w = 0;
    if (h) *h = 0;
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(evas = evas_object_evas_get(editable))))
      return;
    if (!(sd = evas_object_smart_data_get(editable))) return;
@@ -809,6 +859,7 @@ e_editable_enable(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
 
@@ -820,6 +871,7 @@ e_editable_disable(Evas_Object *editable)
 {
    E_Editable_Smart_Data *sd;
 
+   if (evas_object_smart_smart_get(editable) != _e_editable_smart) SMARTERRNR();
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return;
 
@@ -835,7 +887,7 @@ _e_editable_text_insert(Evas_Object *editable, int pos, const char *text)
    E_Editable_Smart_Data *sd;
    int char_length = -1, unicode_length = -1;
    int prev_char_length, new_char_length, new_unicode_length;
-   int index = 0, i = 0;
+   int idx = 0, i = 0;
 
    if ((!editable) || (!(sd = evas_object_smart_data_get(editable))))
      return 0;
@@ -852,7 +904,7 @@ _e_editable_text_insert(Evas_Object *editable, int pos, const char *text)
      }
 
    for (i = 0; i < pos; i++)
-     index = evas_string_char_next_get(sd->text, index, NULL);
+     idx = evas_string_char_next_get(sd->text, idx, NULL);
 
    if ((unicode_length <= 0) || (char_length <= 0)) return 0;
 
@@ -895,9 +947,9 @@ _e_editable_text_insert(Evas_Object *editable, int pos, const char *text)
    sd->unicode_length = new_unicode_length;
    sd->char_length = new_char_length;
 
-   if (prev_char_length > index)
-     memmove(&sd->text[index + char_length], &sd->text[index], prev_char_length - index);
-   strncpy(&sd->text[index], text, char_length);
+   if (prev_char_length > idx)
+     memmove(&sd->text[idx + char_length], &sd->text[idx], prev_char_length - idx);
+   strncpy(&sd->text[idx], text, char_length);
    sd->text[sd->char_length] = '\0';
 
    _e_editable_text_update(editable);
@@ -1091,7 +1143,7 @@ _e_editable_char_geometry_get_from_pos(Evas_Object *editable, int utf_pos, Evas_
    const Evas_Object *text_obj;
    const char *text;
    Evas_Coord x, w;
-   int index = 0, i, last_pos, ret;
+   int idx = 0, i, last_pos, ret;
 
    if (cx) *cx = 0;
    if (cy) *cy = 0;
@@ -1120,9 +1172,9 @@ _e_editable_char_geometry_get_from_pos(Evas_Object *editable, int utf_pos, Evas_
           last_pos = 0;
 
         for (i = 0; i < utf_pos; i++)
-          index = evas_string_char_next_get(text, index, NULL);
+          idx = evas_string_char_next_get(text, idx, NULL);
 
-        ret = evas_object_text_char_pos_get(text_obj, index, &x, cy, &w, ch);
+        ret = evas_object_text_char_pos_get(text_obj, idx, &x, cy, &w, ch);
         if (cx) *cx = x - 1 + (last_pos ? w : 0);
         if (cw) *cw = last_pos ? 1 : w;
         return ret;
