@@ -68,9 +68,8 @@ e_init_show(void)
    else ver = strdup("XvX");
 
    snprintf(buf, sizeof(buf), 
-            "%s/enlightenment/utils/enlightenment_init \'%s\' \'%i\' \'%i\' \'%s\' \'%s\'",
+            "%s/enlightenment/utils/enlightenment_init \'%s\' \'%i\' \'%s\' \'%s\'",
 	    e_prefix_lib_get(), theme,
-	    e_canvas_engine_decide(e_config->evas_engine_init),
 	    e_config->font_hinting, tit, ver);
    printf("RUN INIT: %s\n", buf);
    free(theme);
