@@ -1,15 +1,10 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 
 static Ecore_Exe *_e_intl_input_method_exec = NULL;
 static Ecore_Event_Handler *_e_intl_exit_handler = NULL;
 
-static char *_e_intl_orig_lc_messages = NULL;
-static char *_e_intl_orig_language = NULL;
-static char *_e_intl_orig_lc_all = NULL;
 static char *_e_intl_orig_lang = NULL;
+static char *_e_intl_orig_language = NULL;
 static char *_e_intl_language = NULL;
 
 static char *_e_intl_language_alias = NULL;
@@ -17,12 +12,13 @@ static char *_e_intl_language_alias = NULL;
 static char *_e_intl_orig_xmodifiers = NULL;
 static char *_e_intl_orig_qt_im_module = NULL;
 static char *_e_intl_orig_gtk_im_module = NULL;
+static char *_e_intl_orig_ecore_imf_module = NULL;
 
 static const char *_e_intl_imc_personal_path = NULL;
 static const char *_e_intl_imc_system_path = NULL;
 
-#define E_EXE_STOP(EXE) if (EXE != NULL) { ecore_exe_terminate(EXE); ecore_exe_free(EXE); EXE = NULL; }
-#define E_EXE_IS_VALID(EXE) (!((EXE == NULL) || (EXE[0] == 0)))
+#define E_EXE_STOP(EXE) if (EXE) { ecore_exe_terminate(EXE); ecore_exe_free(EXE); EXE = NULL; }
+#define E_EXE_IS_VALID(EXE) (!((!EXE) || (EXE[0] == 0)))
 
 /* All locale parts */
 #define E_INTL_LOC_ALL		E_INTL_LOC_LANG | \
@@ -30,7 +26,7 @@ static const char *_e_intl_imc_system_path = NULL;
 				E_INTL_LOC_CODESET | \
 				E_INTL_LOC_MODIFIER
 
-/* Locale parts wich are significant when Validating */
+/* Locale parts which are significant when Validating */
 #define E_INTL_LOC_SIGNIFICANT	E_INTL_LOC_LANG | \
 				E_INTL_LOC_REGION | \
 				E_INTL_LOC_CODESET
@@ -53,37 +49,35 @@ static Eina_Bool 	 _e_intl_locale_hash_free_cb(const Eina_Hash *hash, const void
 static Eina_Bool	 _e_intl_cb_exit(void *data, int type, void *event);
 static Eina_List 	*_e_intl_imc_dir_scan(const char *dir);
 
-EAPI int
+EINTERN int
 e_intl_init(void)
 {
    char *s;
 
    e_intl_data_init();
 
-   if ((s = getenv("LC_MESSAGES"))) _e_intl_orig_lc_messages = strdup(s);
-   if ((s = getenv("LANGUAGE"))) _e_intl_orig_language = strdup(s);
-   if ((s = getenv("LC_ALL"))) _e_intl_orig_lc_all = strdup(s);
    if ((s = getenv("LANG"))) _e_intl_orig_lang = strdup(s);
+   if ((s = getenv("LANGUAGE"))) _e_intl_orig_language = strdup(s);
 
    if ((s = getenv("GTK_IM_MODULE"))) _e_intl_orig_gtk_im_module = strdup(s);
    if ((s = getenv("QT_IM_MODULE"))) _e_intl_orig_qt_im_module = strdup(s);
    if ((s = getenv("XMODIFIERS"))) _e_intl_orig_xmodifiers = strdup(s);
+   if ((s = getenv("ECORE_IMF_MODULE"))) _e_intl_orig_ecore_imf_module = strdup(s);
 
    return 1;
 }
 
-EAPI int
+EINTERN int
 e_intl_shutdown(void)
 {
    E_FREE(_e_intl_language);
-   E_FREE(_e_intl_orig_lc_messages);
-   E_FREE(_e_intl_orig_language);
-   E_FREE(_e_intl_orig_lc_all);
    E_FREE(_e_intl_orig_lang);
+   E_FREE(_e_intl_orig_language);
 
    E_FREE(_e_intl_orig_gtk_im_module);
    E_FREE(_e_intl_orig_qt_im_module);
    E_FREE(_e_intl_orig_xmodifiers);
+   E_FREE(_e_intl_orig_ecore_imf_module);
 
    if (_e_intl_imc_personal_path)
      eina_stringshare_del(_e_intl_imc_personal_path);
@@ -96,7 +90,7 @@ e_intl_shutdown(void)
 }
 
 /* Setup configuration settings and start services */
-EAPI int
+EINTERN int
 e_intl_post_init(void)
 {
    if ((e_config->language) && (e_config->language[0] != 0))
@@ -112,7 +106,7 @@ e_intl_post_init(void)
    return 1;
 }
 
-EAPI int
+EINTERN int
 e_intl_post_shutdown(void)
 {
    if (_e_intl_exit_handler)
@@ -151,13 +145,8 @@ e_intl_language_set(const char *lang)
     */
    if (!lang)
      {
-	e_util_env_set("LC_MESSAGES", _e_intl_orig_lc_messages);
-	e_util_env_set("LANGUAGE", _e_intl_orig_language);
-	e_util_env_set("LC_ALL", _e_intl_orig_lc_all);
 	e_util_env_set("LANG", _e_intl_orig_lang);
 
-	lang = getenv("LC_MESSAGES");
-	if (!lang) lang = getenv("LANGUAGE");
 	if (!lang) lang = getenv("LC_ALL");
 	if (!lang) lang = getenv("LANG");
 
@@ -200,26 +189,25 @@ e_intl_language_set(const char *lang)
 	/* Only set env vars is a non NULL locale was passed */
 	if (set_envars)
 	  {
-	     e_util_env_set("LANGUAGE", _e_intl_language);
-	     e_util_env_set("LANG", _e_intl_language);
-	     e_util_env_set("LC_ALL", _e_intl_language);
-	     e_util_env_set("LC_MESSAGES", _e_intl_language);
+             e_util_env_set("LANG", lang);
+             /* Unset LANGUAGE, apparently causes issues if set */
+             e_util_env_set("LANGUAGE", NULL);
 	  }
 
-    	setlocale(LC_ALL, _e_intl_language);
+	setlocale(LC_ALL, lang);
         if (_e_intl_language)
 	  {
              char *locale_path;
 
              locale_path = _e_intl_language_path_find(_e_intl_language_alias);
-             if (locale_path == NULL)
+             if (!locale_path)
 	       {
 		  E_Locale_Parts *locale_parts;
 
 		  locale_parts = e_intl_locale_parts_get(_e_intl_language_alias);
 
 		  /* If locale is C or some form of en don't report an error */
-		  if ((locale_parts == NULL) && 
+		  if ((!locale_parts) && 
 		      (strcmp(_e_intl_language_alias, "C")))
 		    {
 		       fprintf(stderr,
@@ -329,6 +317,7 @@ e_intl_input_method_set(const char *imc_path)
 	e_util_env_set("GTK_IM_MODULE", _e_intl_orig_gtk_im_module);
         e_util_env_set("QT_IM_MODULE", _e_intl_orig_qt_im_module);
         e_util_env_set("XMODIFIERS", _e_intl_orig_xmodifiers);
+	e_util_env_set("ECORE_IMF_MODULE", _e_intl_orig_ecore_imf_module);
      }
 
    if (imc_path)
@@ -347,6 +336,7 @@ e_intl_input_method_set(const char *imc_path)
 	          e_util_env_set("GTK_IM_MODULE", imc->gtk_im_module);
 	          e_util_env_set("QT_IM_MODULE", imc->qt_im_module);
 	          e_util_env_set("XMODIFIERS", imc->xmodifiers);
+	          e_util_env_set("ECORE_IMF_MODULE", imc->ecore_imf_module);
 
 		  E_EXE_STOP(_e_intl_input_method_exec);
 
@@ -393,7 +383,7 @@ e_intl_input_method_list(void)
 const char *
 e_intl_imc_personal_path_get(void)
 {
-   if (_e_intl_imc_personal_path == NULL)
+   if (!_e_intl_imc_personal_path)
      {
 	char buf[4096];
 
@@ -406,7 +396,7 @@ e_intl_imc_personal_path_get(void)
 const char *
 e_intl_imc_system_path_get(void)
 {
-   if (_e_intl_imc_system_path == NULL)
+   if (!_e_intl_imc_system_path)
      {
 	char buf[4096];
 
@@ -417,7 +407,7 @@ e_intl_imc_system_path_get(void)
 }
 
 static Eina_Bool
-_e_intl_cb_exit(__UNUSED__ void *data, __UNUSED__ int type, void *event)
+_e_intl_cb_exit(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Exe_Event_Del *ev;
 
@@ -472,7 +462,7 @@ _e_intl_language_path_find(char *language)
 
    search_list = _e_intl_locale_search_order_get(language);
 
-   if (search_list == NULL) return NULL;
+   if (!search_list) return NULL;
 
    directory = NULL;
    found = 0;
@@ -549,11 +539,11 @@ _e_intl_locale_alias_get(const char *language)
    char *lower_language;
    unsigned int i;
 
-   if ((language == NULL) || (!strncmp(language, "POSIX", strlen("POSIX"))))
+   if ((!language) || (!strncmp(language, "POSIX", strlen("POSIX"))))
      return strdup("C");
 
    alias_hash = _e_intl_locale_alias_hash_get();
-   if (alias_hash == NULL) /* No alias file available */
+   if (!alias_hash) /* No alias file available */
      return strdup(language);
 
    lower_language = malloc(strlen(language) + 1);
@@ -758,7 +748,7 @@ e_intl_locale_parts_get(const char *locale)
 EAPI void
 e_intl_locale_parts_free(E_Locale_Parts *locale_parts)
 {
-   if (locale_parts != NULL)
+   if (locale_parts)
      {
 	if (locale_parts->lang) eina_stringshare_del(locale_parts->lang);
 	if (locale_parts->region) eina_stringshare_del(locale_parts->region);
@@ -794,6 +784,8 @@ e_intl_locale_parts_combine(E_Locale_Parts *locale_parts, int mask)
    if (mask & E_INTL_LOC_MODIFIER)
      locale_size += strlen(locale_parts->modifier) + 1;
 
+   if (!locale_size) return NULL;
+
    /* Allocate memory */
    locale = (char *) malloc(locale_size);
    locale[0] = 0;
@@ -884,7 +876,7 @@ _e_intl_locale_validate(const char *locale)
    locale_lr = 
      e_intl_locale_parts_combine(locale_parts, 
 				 E_INTL_LOC_LANG | E_INTL_LOC_REGION);
-   if (locale_lr == NULL)
+   if (!locale_lr)
      {
 	/* Not valid locale, maybe its an alias */
 	locale_lr = strdup(locale);
@@ -917,7 +909,7 @@ _e_intl_locale_validate(const char *locale)
 		 (!strcmp(locale_lr, locale_lr_next)))
 	       {
 		  /* Matched lang/region part, now if CS matches */
-		  if ((locale_parts->codeset == NULL) && (locale_parts_next->codeset == NULL))
+		  if ((!locale_parts->codeset) && (!locale_parts_next->codeset))
 		    {
 		       /* Lang/Region parts match and no charsets,
 			* we have a match
@@ -998,7 +990,7 @@ _e_intl_locale_search_order_get(const char *locale)
    int mask;
 
    locale_parts = e_intl_locale_parts_get(locale);
-   if (locale_parts == NULL) return NULL;
+   if (!locale_parts) return NULL;
 
    search_list = NULL;
    for (mask = E_INTL_LOC_ALL; mask >= E_INTL_LOC_LANG; mask--)
@@ -1025,7 +1017,7 @@ _e_intl_imc_dir_scan(const char *dir)
 
    EINA_LIST_FREE(files, file)
      {
-	if (strstr(file, ".imc") != NULL)
+	if (strstr(file, ".imc"))
 	  {
 	     char buf[PATH_MAX];
 	     
