@@ -44,7 +44,6 @@ EAPI int          e_util_menu_item_edje_icon_list_set(E_Menu_Item *mi, const cha
 EAPI int          e_util_edje_icon_check(const char *name);
 EAPI int          e_util_edje_icon_set(Evas_Object *obj, const char *name);
 EAPI int          e_util_icon_theme_set(Evas_Object *obj, const char *icon);
-EAPI int          e_util_menu_item_edje_icon_set(E_Menu_Item *mi, const char *name);
 EAPI unsigned int e_util_icon_size_normalize(unsigned int desired);
 EAPI int          e_util_menu_item_theme_icon_set(E_Menu_Item *mi, const char *icon);
 EAPI E_Container *e_util_container_window_find(Ecore_X_Window win);
@@ -68,7 +67,9 @@ EAPI int          e_util_dir_check(const char *dir);
 EAPI void         e_util_defer_object_del(E_Object *obj);
 EAPI const char  *e_util_winid_str_get(Ecore_X_Window win);
 EAPI void         e_util_win_auto_resize_fill(E_Win *win);
-EAPI Eina_Bool    e_util_module_config_check(const char *module_name, int conf, int epoch, int version);
+/* check if loaded config version matches the current version, show a
+   dialog warning if loaded version is older or newer than current */
+EAPI Eina_Bool    e_util_module_config_check(const char *module_name, int loaded, int current);
 
 EAPI E_Dialog                   *e_util_image_import_settings_new(const char *path, void (*cb)(void *data, const char *path, Eina_Bool ok, Eina_Bool external, int quality, E_Image_Import_Mode mode), const void *data);
 EAPI E_Util_Image_Import_Handle *e_util_image_import(const char *image_path, const char *edje_path, const char *edje_group, Eina_Bool external, int quality, E_Image_Import_Mode mode, void (*cb)(void *data, Eina_Bool ok, const char *image_path, const char *edje_path), const void *data);
