@@ -34,14 +34,14 @@ static void _bluez_popup_update(E_Bluez_Instance *inst);
 
 struct bluez_pincode_data
 {
-   void (*cb)(struct bluez_pincode_data *d);
-   DBusMessage *msg;
+   void                    (*cb)(struct bluez_pincode_data *d);
+   DBusMessage            *msg;
    E_Bluez_Module_Context *ctxt;
-   char *pincode;
-   const char *alias;
-   E_Dialog *dia;
-   Evas_Object *entry;
-   Eina_Bool canceled;
+   char                   *pincode;
+   const char             *alias;
+   E_Dialog               *dia;
+   Evas_Object            *entry;
+   Eina_Bool               canceled;
 };
 
 const char *
@@ -67,25 +67,27 @@ _bluez_devices_clear(E_Bluez_Instance *inst)
    E_Bluez_Instance_Device *d;
    EINA_LIST_FREE(inst->devices, d)
      {
-	eina_stringshare_del(d->address);
-	eina_stringshare_del(d->alias);
-	free(d);
+        eina_stringshare_del(d->address);
+        eina_stringshare_del(d->alias);
+        free(d);
      }
    inst->address = NULL;
    inst->alias = NULL;
 }
 
 static void
-_bluez_discovery_cb(void *data, DBusMessage *msg __UNUSED__, DBusError *error)
+_bluez_discovery_cb(void            *data,
+                    DBusMessage *msg __UNUSED__,
+                    DBusError       *error)
 {
-   E_Bluez_Instance *inst= data;
+   E_Bluez_Instance *inst = data;
    char *label;
 
    if (error && dbus_error_is_set(error))
      {
-	_bluez_dbus_error_show(_("Cannot change adapter's discovery."), error);
-	dbus_error_free(error);
-	return;
+        _bluez_dbus_error_show(_("Cannot change adapter's discovery."), error);
+        dbus_error_free(error);
+        return;
      }
 
    inst->discovering = !inst->discovering;
@@ -95,17 +97,19 @@ _bluez_discovery_cb(void *data, DBusMessage *msg __UNUSED__, DBusError *error)
 }
 
 static void
-_bluez_create_paired_device_cb(void *data, DBusMessage *msg __UNUSED__, DBusError *error)
+_bluez_create_paired_device_cb(void            *data,
+                               DBusMessage *msg __UNUSED__,
+                               DBusError       *error)
 {
    const char *alias = data;
 
    if (error && dbus_error_is_set(error))
      {
-	if (strcmp(error->name, "org.bluez.Error.AlreadyExists") != 0)
-	  _bluez_dbus_error_show(_("Cannot pair with device."), error);
-	dbus_error_free(error);
-	eina_stringshare_del(alias);
-	return;
+        if (strcmp(error->name, "org.bluez.Error.AlreadyExists") != 0)
+          _bluez_dbus_error_show(_("Cannot pair with device."), error);
+        dbus_error_free(error);
+        eina_stringshare_del(alias);
+        return;
      }
 
    e_util_dialog_show
@@ -114,25 +118,27 @@ _bluez_create_paired_device_cb(void *data, DBusMessage *msg __UNUSED__, DBusErro
 }
 
 static void
-_bluez_toggle_powered_cb(void *data, DBusMessage *msg __UNUSED__, DBusError *error)
+_bluez_toggle_powered_cb(void            *data,
+                         DBusMessage *msg __UNUSED__,
+                         DBusError       *error)
 {
    E_Bluez_Instance *inst = data;
 
    if ((!error) || (!dbus_error_is_set(error)))
      {
-	inst->powered_pending = EINA_FALSE;
-	inst->powered = !inst->powered;
+        inst->powered_pending = EINA_FALSE;
+        inst->powered = !inst->powered;
 
-	if (!inst->powered)
-	  {
-	     _bluez_devices_clear(inst);
+        if (!inst->powered)
+          {
+             _bluez_devices_clear(inst);
 
-	     if (inst->popup)
-	       _bluez_popup_update(inst);
-	  }
+             if (inst->popup)
+               _bluez_popup_update(inst);
+          }
 
-	_bluez_gadget_update(inst);
-	return;
+        _bluez_gadget_update(inst);
+        return;
      }
 
    _bluez_dbus_error_show(_("Cannot toggle adapter's powered."), error);
@@ -146,34 +152,35 @@ _bluez_toggle_powered(E_Bluez_Instance *inst)
 
    if ((!inst) || (!inst->ctxt->has_manager))
      {
-	_bluez_operation_error_show(_("BlueZ Daemon is not running."));
-	return;
+        _bluez_operation_error_show(_("BlueZ Daemon is not running."));
+        return;
      }
 
    if (!inst->adapter)
      {
-	_bluez_operation_error_show(_("No bluetooth adapter."));
-	return;
+        _bluez_operation_error_show(_("No bluetooth adapter."));
+        return;
      }
 
    if (!e_bluez_adapter_powered_get(inst->adapter, &powered))
      {
-	_bluez_operation_error_show(_("Query adapter's powered."));
-	return;
+        _bluez_operation_error_show(_("Query adapter's powered."));
+        return;
      }
 
    powered = !powered;
 
    if (!e_bluez_adapter_powered_set
-       (inst->adapter, powered, _bluez_toggle_powered_cb, inst))
+         (inst->adapter, powered, _bluez_toggle_powered_cb, inst))
      {
-	_bluez_operation_error_show(_("Query adapter's powered."));
-	return;
+        _bluez_operation_error_show(_("Query adapter's powered."));
+        return;
      }
 }
 
 static void
-_bluez_cb_toggle_powered(E_Object *obj __UNUSED__, const char *params __UNUSED__)
+_bluez_cb_toggle_powered(E_Object *obj      __UNUSED__,
+                         const char *params __UNUSED__)
 {
    E_Bluez_Module_Context *ctxt;
    const Eina_List *l;
@@ -190,7 +197,9 @@ _bluez_cb_toggle_powered(E_Object *obj __UNUSED__, const char *params __UNUSED__
 static void _bluez_popup_del(E_Bluez_Instance *inst);
 
 static Eina_Bool
-_bluez_popup_input_window_mouse_up_cb(void *data, int type __UNUSED__, void *event)
+_bluez_popup_input_window_mouse_up_cb(void    *data,
+                                      int type __UNUSED__,
+                                      void    *event)
 {
    Ecore_Event_Mouse_Button *ev = event;
    E_Bluez_Instance *inst = data;
@@ -204,7 +213,9 @@ _bluez_popup_input_window_mouse_up_cb(void *data, int type __UNUSED__, void *eve
 }
 
 static Eina_Bool
-_bluez_popup_input_window_key_down_cb(void *data, int type __UNUSED__, void *event)
+_bluez_popup_input_window_key_down_cb(void    *data,
+                                      int type __UNUSED__,
+                                      void    *event)
 {
    Ecore_Event_Key *ev = event;
    E_Bluez_Instance *inst = data;
@@ -252,17 +263,18 @@ _bluez_popup_input_window_create(E_Bluez_Instance *inst)
 
    inst->ui.input.mouse_up =
      ecore_event_handler_add(ECORE_EVENT_MOUSE_BUTTON_UP,
-			     _bluez_popup_input_window_mouse_up_cb, inst);
+                             _bluez_popup_input_window_mouse_up_cb, inst);
 
    inst->ui.input.key_down =
      ecore_event_handler_add(ECORE_EVENT_KEY_DOWN,
-			     _bluez_popup_input_window_key_down_cb, inst);
+                             _bluez_popup_input_window_key_down_cb, inst);
 
    inst->ui.input.win = w;
 }
 
 static void
-_bluez_popup_cb_powered_changed(void *data, Evas_Object *obj)
+_bluez_popup_cb_powered_changed(void        *data,
+                                Evas_Object *obj)
 {
    E_Bluez_Instance *inst = data;
    E_Bluez_Module_Context *ctxt = inst->ctxt;
@@ -270,22 +282,22 @@ _bluez_popup_cb_powered_changed(void *data, Evas_Object *obj)
 
    if ((!ctxt) || (!ctxt->has_manager))
      {
-	_bluez_operation_error_show(_("BlueZ Daemon is not running."));
-	return;
+        _bluez_operation_error_show(_("BlueZ Daemon is not running."));
+        return;
      }
 
    if (!inst->adapter)
      {
-	_bluez_operation_error_show(_("No bluetooth adapter."));
-	return;
+        _bluez_operation_error_show(_("No bluetooth adapter."));
+        return;
      }
 
    if (!e_bluez_adapter_powered_set
-       (inst->adapter, powered, _bluez_toggle_powered_cb, inst))
+         (inst->adapter, powered, _bluez_toggle_powered_cb, inst))
      {
-	_bluez_operation_error_show
-	  (_("Cannot toggle adapter's powered."));
-	return;
+        _bluez_operation_error_show
+          (_("Cannot toggle adapter's powered."));
+        return;
      }
 
    inst->powered_pending = EINA_TRUE;
@@ -298,8 +310,8 @@ _bluez_pincode_ask_cb(struct bluez_pincode_data *d)
 
    if (!d->pincode)
      {
-	e_util_dialog_show(_("Bluetooth Manager"), _("Invalid Pin Code."));
-	return;
+        e_util_dialog_show(_("Bluetooth Manager"), _("Invalid Pin Code."));
+        return;
      }
 
    reply = dbus_message_new_method_return(d->msg);
@@ -311,7 +323,8 @@ _bluez_pincode_ask_cb(struct bluez_pincode_data *d)
 }
 
 static void
-bluez_pincode_ask_ok(void *data, E_Dialog *dia)
+bluez_pincode_ask_ok(void     *data,
+                     E_Dialog *dia)
 {
    struct bluez_pincode_data *d = data;
    d->canceled = EINA_FALSE;
@@ -319,7 +332,8 @@ bluez_pincode_ask_ok(void *data, E_Dialog *dia)
 }
 
 static void
-bluez_pincode_ask_cancel(void *data, E_Dialog *dia)
+bluez_pincode_ask_cancel(void     *data,
+                         E_Dialog *dia)
 {
    struct bluez_pincode_data *d = data;
    d->canceled = EINA_TRUE;
@@ -344,7 +358,10 @@ bluez_pincode_ask_del(void *data)
 }
 
 static void
-bluez_pincode_ask_key_down(void *data, Evas *e __UNUSED__, Evas_Object *o __UNUSED__, void *event)
+bluez_pincode_ask_key_down(void          *data,
+                           Evas *e        __UNUSED__,
+                           Evas_Object *o __UNUSED__,
+                           void          *event)
 {
    Evas_Event_Key_Down *ev = event;
    struct bluez_pincode_data *d = data;
@@ -356,7 +373,10 @@ bluez_pincode_ask_key_down(void *data, Evas *e __UNUSED__, Evas_Object *o __UNUS
 }
 
 static void
-bluez_pincode_ask(void (*cb)(struct bluez_pincode_data *), DBusMessage *msg, const char *alias, E_Bluez_Module_Context *ctxt)
+bluez_pincode_ask(void                    (*cb)(struct bluez_pincode_data *),
+                  DBusMessage            *msg,
+                  const char             *alias,
+                  E_Bluez_Module_Context *ctxt)
 {
    struct bluez_pincode_data *d;
    Evas_Object *list, *o;
@@ -389,9 +409,9 @@ bluez_pincode_ask(void (*cb)(struct bluez_pincode_data *), DBusMessage *msg, con
 
    o = edje_object_add(evas);
    e_theme_edje_object_set(o, "base/theme/dialog",
-			   "e/widgets/dialog/text");
+                           "e/widgets/dialog/text");
    snprintf(buf, sizeof(buf),
-	    _("Enter the PIN code: "));
+            _("Enter the PIN code: "));
    edje_object_part_text_set(o, "e.textblock.message", buf);
    edje_object_size_min_calc(o, &mw, &mh);
    evas_object_size_hint_min_set(o, mw, mh);
@@ -418,7 +438,7 @@ bluez_pincode_ask(void (*cb)(struct bluez_pincode_data *), DBusMessage *msg, con
 
    evas_object_event_callback_add
      (d->dia->bg_object, EVAS_CALLBACK_KEY_DOWN,
-      bluez_pincode_ask_key_down, d);
+     bluez_pincode_ask_key_down, d);
 
    e_object_del_attach_func_set
      (E_OBJECT(d->dia), bluez_pincode_ask_del);
@@ -433,8 +453,9 @@ bluez_pincode_ask(void (*cb)(struct bluez_pincode_data *), DBusMessage *msg, con
    ctxt->agent.pending = eina_list_append(ctxt->agent.pending, d->dia);
 }
 
-static DBusMessage*
-_bluez_request_pincode_cb(E_DBus_Object *obj, DBusMessage *msg)
+static DBusMessage *
+_bluez_request_pincode_cb(E_DBus_Object *obj,
+                          DBusMessage   *msg)
 {
    E_Bluez_Module_Context *ctxt = e_dbus_object_data_get(obj);
    E_Bluez_Element *element;
@@ -444,7 +465,7 @@ _bluez_request_pincode_cb(E_DBus_Object *obj, DBusMessage *msg)
    // TODO: seems that returning NULL is causing pin code rquest to be canceled!
 
    if (dbus_message_get_args(msg, NULL, DBUS_TYPE_OBJECT_PATH, &path,
-			     DBUS_TYPE_INVALID) == FALSE)
+                             DBUS_TYPE_INVALID) == FALSE)
      return NULL;
 
    element = e_bluez_device_get(path);
@@ -452,11 +473,11 @@ _bluez_request_pincode_cb(E_DBus_Object *obj, DBusMessage *msg)
      alias = path;
    else
      {
-	if (!e_bluez_device_alias_get(element, &alias))
-	  {
-	     if (!e_bluez_device_name_get(element, &alias))
-	       alias = path;
-	  }
+        if (!e_bluez_device_alias_get(element, &alias))
+          {
+             if (!e_bluez_device_name_get(element, &alias))
+               alias = path;
+          }
      }
    // TODO: find out why alias == address, then remove debug:
    fprintf(stderr, ">>> request pin code of '%s' (%s)\n", alias, path);
@@ -465,7 +486,8 @@ _bluez_request_pincode_cb(E_DBus_Object *obj, DBusMessage *msg)
 }
 
 static void
-_bluez_popup_cb_scan(void *data, void *data2 __UNUSED__)
+_bluez_popup_cb_scan(void       *data,
+                     void *data2 __UNUSED__)
 {
    E_Bluez_Instance *inst = data;
    int ret;
@@ -474,17 +496,17 @@ _bluez_popup_cb_scan(void *data, void *data2 __UNUSED__)
      ret = 0;
    else if (inst->discovering)
      ret = e_bluez_adapter_stop_discovery
-       (inst->adapter, _bluez_discovery_cb, inst);
+         (inst->adapter, _bluez_discovery_cb, inst);
    else
      {
-	inst->last_scan = ecore_loop_time_get();
+        inst->last_scan = ecore_loop_time_get();
 
-	_bluez_devices_clear(inst);
+        _bluez_devices_clear(inst);
 
-	ret = e_bluez_adapter_start_discovery
-	  (inst->adapter, _bluez_discovery_cb, inst);
+        ret = e_bluez_adapter_start_discovery
+            (inst->adapter, _bluez_discovery_cb, inst);
 
-	_bluez_popup_update(inst);
+        _bluez_popup_update(inst);
      }
 
    if (!ret)
@@ -492,7 +514,8 @@ _bluez_popup_cb_scan(void *data, void *data2 __UNUSED__)
 }
 
 static void
-_bluez_popup_cb_controls(void *data, void *data2 __UNUSED__)
+_bluez_popup_cb_controls(void       *data,
+                         void *data2 __UNUSED__)
 {
    E_Bluez_Instance *inst = data;
    if (inst->popup)
@@ -519,38 +542,40 @@ _bluez_popup_device_selected(void *data)
 
    if (!address)
      {
-	ERR("no device selected for pairing.");
-	return;
+        ERR("no device selected for pairing.");
+        return;
      }
 
    inst->alias = address;
    EINA_LIST_FOREACH(inst->devices, l, d)
      {
-	if (address == d->alias)
-	  {
-	     inst->alias = d->alias;
-	     break;
-	  }
+        if (address == d->alias)
+          {
+             inst->alias = d->alias;
+             break;
+          }
      }
 
    if (!inst->alias)
      {
-	ERR("device %s does not have an alias.", address);
-	return;
+        ERR("device %s does not have an alias.", address);
+        return;
      }
 
    alias = eina_stringshare_ref(inst->alias);
    if (!e_bluez_adapter_create_paired_device
-       (inst->adapter, _e_bluez_agent_path, cap, address,
-	_bluez_create_paired_device_cb, alias))
+         (inst->adapter, _e_bluez_agent_path, cap, address,
+         _bluez_create_paired_device_cb, alias))
      {
-	eina_stringshare_del(alias);
-	return;
+        eina_stringshare_del(alias);
+        return;
      }
 }
 
 static Eina_Bool
-_bluez_event_devicefound(void *data, int type __UNUSED__, void *event __UNUSED__)
+_bluez_event_devicefound(void       *data,
+                         int type    __UNUSED__,
+                         void *event)
 {
    E_Bluez_Module_Context *ctxt = data;
    E_Bluez_Device_Found *device = event;
@@ -565,38 +590,38 @@ _bluez_event_devicefound(void *data, int type __UNUSED__, void *event __UNUSED__
 
    EINA_LIST_FOREACH(ctxt->instances, l_inst, inst)
      {
-	const Eina_List *l_dev;
-	E_Bluez_Instance_Device *dev;
-	Eina_Bool found = EINA_FALSE;
+        const Eina_List *l_dev;
+        E_Bluez_Instance_Device *dev;
+        Eina_Bool found = EINA_FALSE;
 
-	if (inst->adapter != device->adapter) continue;
+        if (inst->adapter != device->adapter) continue;
 
-	EINA_LIST_FOREACH(inst->devices, l_dev, dev)
-	  {
-	     if (dev->address == device->name)
-	       {
-		  found = EINA_TRUE;
-		  break;
-	       }
-	  }
+        EINA_LIST_FOREACH(inst->devices, l_dev, dev)
+          {
+             if (dev->address == device->name)
+               {
+                  found = EINA_TRUE;
+                  break;
+               }
+          }
 
-	if (found) continue;
+        if (found) continue;
 
-	dev = malloc(sizeof(E_Bluez_Instance_Device));
-	if (!dev) continue;
+        dev = malloc(sizeof(E_Bluez_Instance_Device));
+        if (!dev) continue;
 
-	dev->address = eina_stringshare_ref(device->name);
-	dev->alias = eina_stringshare_ref(alias);
+        dev->address = eina_stringshare_ref(device->name);
+        dev->alias = eina_stringshare_ref(alias);
 
-	inst->devices = eina_list_append(inst->devices, dev);
+        inst->devices = eina_list_append(inst->devices, dev);
 
-	if (inst->ui.list)
-	  {
-	     e_widget_ilist_append
-	       (inst->ui.list, NULL, dev->alias,
-		_bluez_popup_device_selected, inst, dev->address);
-	     e_widget_ilist_go(inst->ui.list);
-	  }
+        if (inst->ui.list)
+          {
+             e_widget_ilist_append
+               (inst->ui.list, NULL, dev->alias,
+               _bluez_popup_device_selected, inst, dev->address);
+             e_widget_ilist_go(inst->ui.list);
+          }
      }
 
    return 1;
@@ -620,15 +645,15 @@ _bluez_popup_update(E_Bluez_Instance *inst)
 
    EINA_LIST_FOREACH(inst->devices, l, d)
      {
-	e_widget_ilist_append
-	  (inst->ui.list, NULL, d->alias,
-	   _bluez_popup_device_selected, inst, d->address);
+        e_widget_ilist_append
+          (inst->ui.list, NULL, d->alias,
+          _bluez_popup_device_selected, inst, d->address);
      }
 
    if (selected >= 0)
      {
-	inst->first_selection = EINA_TRUE;
-	e_widget_ilist_selected_set(list, selected);
+        inst->first_selection = EINA_TRUE;
+        e_widget_ilist_selected_set(list, selected);
      }
    else
      inst->first_selection = EINA_FALSE;
@@ -660,28 +685,28 @@ _bluez_popup_new(E_Bluez_Instance *inst)
 
    if (inst->popup)
      {
-	e_gadcon_popup_show(inst->popup);
-	return;
+        e_gadcon_popup_show(inst->popup);
+        return;
      }
 
    if (!inst->adapter)
      {
-	_bluez_operation_error_show(_("No bluetooth adapter."));
-	return;
+        _bluez_operation_error_show(_("No bluetooth adapter."));
+        return;
      }
 
    if (!e_bluez_adapter_discovering_get(inst->adapter, &b))
      {
-	_bluez_operation_error_show(_("Can't get Discovering property"));
-	return;
+        _bluez_operation_error_show(_("Can't get Discovering property"));
+        return;
      }
    inst->discovering = b;
    // maybe auto-scan if did not in the last 30 minutes?
    // seems scan will hurt things like bluetooth audio playback, so don't do it
    if ((!inst->discovering) && (inst->last_scan <= 0.0) && (inst->ui.powered))
      {
-	label = _("Stop Scan");
-	needs_scan = EINA_TRUE;
+        label = _("Stop Scan");
+        needs_scan = EINA_TRUE;
      }
    else
      label = inst->discovering ? _("Stop Scan") : _("Start Scan");
@@ -703,11 +728,11 @@ _bluez_popup_new(E_Bluez_Instance *inst)
    e_widget_list_object_append(ol, inst->ui.powered, 1, 0, 0.5);
 
    inst->ui.button = e_widget_button_add
-     (evas, label, NULL, _bluez_popup_cb_scan, inst, NULL);
+       (evas, label, NULL, _bluez_popup_cb_scan, inst, NULL);
    e_widget_list_object_append(ol, inst->ui.button, 1, 0, 0.5);
 
    inst->ui.control = e_widget_button_add
-     (evas, _("Controls"), NULL, _bluez_popup_cb_controls, inst, NULL);
+       (evas, _("Controls"), NULL, _bluez_popup_cb_controls, inst, NULL);
    e_widget_list_object_append(ol, inst->ui.control, 1, 0, 0.5);
 
    _bluez_popup_update(inst);
@@ -725,20 +750,23 @@ _bluez_popup_new(E_Bluez_Instance *inst)
 }
 
 static void
-_bluez_menu_cb_post(void *data, E_Menu *menu __UNUSED__)
+_bluez_menu_cb_post(void        *data,
+                    E_Menu *menu __UNUSED__)
 {
    E_Bluez_Instance *inst = data;
    if ((!inst) || (!inst->menu))
      return;
    if (inst->menu)
      {
-	e_object_del(E_OBJECT(inst->menu));
-	inst->menu = NULL;
+        e_object_del(E_OBJECT(inst->menu));
+        inst->menu = NULL;
      }
 }
 
 static void
-_bluez_menu_cb_cfg(void *data, E_Menu *menu __UNUSED__, E_Menu_Item *mi __UNUSED__)
+_bluez_menu_cb_cfg(void           *data,
+                   E_Menu *menu    __UNUSED__,
+                   E_Menu_Item *mi __UNUSED__)
 {
    E_Bluez_Instance *inst = data;
    if (inst->popup)
@@ -751,29 +779,28 @@ _bluez_menu_cb_cfg(void *data, E_Menu *menu __UNUSED__, E_Menu_Item *mi __UNUSED
 }
 
 static void
-_bluez_menu_new(E_Bluez_Instance *inst, Evas_Event_Mouse_Down *ev)
+_bluez_menu_new(E_Bluez_Instance      *inst,
+                Evas_Event_Mouse_Down *ev)
 {
    E_Zone *zone;
-   E_Menu *ma, *mg;
+   E_Menu *m;
    E_Menu_Item *mi;
    int x, y;
 
    zone = e_util_zone_current_get(e_manager_current_get());
 
-   ma = e_menu_new();
-   e_menu_post_deactivate_callback_set(ma, _bluez_menu_cb_post, inst);
-   inst->menu = ma;
-
-   mg = e_menu_new();
-
-   mi = e_menu_item_new(mg);
+   m = e_menu_new();
+   mi = e_menu_item_new(m);
    e_menu_item_label_set(mi, _("Settings"));
    e_util_menu_item_theme_icon_set(mi, "configure");
    e_menu_item_callback_set(mi, _bluez_menu_cb_cfg, inst);
 
-   e_gadcon_client_util_menu_items_append(inst->gcc, ma, mg, 0);
+   m = e_gadcon_client_util_menu_items_append(inst->gcc, m, 0);
+   e_menu_post_deactivate_callback_set(m, _bluez_menu_cb_post, inst);
+   inst->menu = m;
+
    e_gadcon_canvas_zone_geometry_get(inst->gcc->gadcon, &x, &y, NULL, NULL);
-   e_menu_activate_mouse(ma, zone, x + ev->output.x, y + ev->output.y,
+   e_menu_activate_mouse(m, zone, x + ev->output.x, y + ev->output.y,
                          1, 1, E_MENU_POP_DIRECTION_AUTO, ev->timestamp);
    evas_event_feed_mouse_up(inst->gcc->gadcon->evas, ev->button,
                             EVAS_BUTTON_NONE, ev->timestamp, NULL);
@@ -791,7 +818,7 @@ _bluez_tip_new(E_Bluez_Instance *inst)
 
    inst->o_tip = edje_object_add(e);
    e_theme_edje_object_set(inst->o_tip, "base/theme/modules/bluez/tip",
-			   "e/modules/bluez/tip");
+                           "e/modules/bluez/tip");
 
    _bluez_tip_update(inst);
 
@@ -809,7 +836,10 @@ _bluez_tip_del(E_Bluez_Instance *inst)
 }
 
 static void
-_bluez_cb_mouse_down(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED__, void *event)
+_bluez_cb_mouse_down(void            *data,
+                     Evas *evas       __UNUSED__,
+                     Evas_Object *obj __UNUSED__,
+                     void            *event)
 {
    E_Bluez_Instance *inst;
    Evas_Event_Mouse_Down *ev;
@@ -821,10 +851,10 @@ _bluez_cb_mouse_down(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSE
    ev = event;
    if (ev->button == 1)
      {
-	if (!inst->popup)
-	  _bluez_popup_new(inst);
-	else
-	  _bluez_popup_del(inst);
+        if (!inst->popup)
+          _bluez_popup_new(inst);
+        else
+          _bluez_popup_del(inst);
      }
    else if (ev->button == 2)
      _bluez_toggle_powered(inst);
@@ -833,7 +863,10 @@ _bluez_cb_mouse_down(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSE
 }
 
 static void
-_bluez_cb_mouse_in(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED__, void *event __UNUSED__)
+_bluez_cb_mouse_in(void            *data,
+                   Evas *evas       __UNUSED__,
+                   Evas_Object *obj __UNUSED__,
+                   void *event      __UNUSED__)
 {
    E_Bluez_Instance *inst = data;
 
@@ -844,11 +877,13 @@ _bluez_cb_mouse_in(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED_
 }
 
 static void
-_bluez_cb_mouse_out(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED__, void *event __UNUSED__)
+_bluez_cb_mouse_out(void            *data,
+                    Evas *evas       __UNUSED__,
+                    Evas_Object *obj __UNUSED__,
+                    void *event      __UNUSED__)
 {
    E_Bluez_Instance *inst = data;
 
-
    if (!inst->tip)
      return;
 
@@ -856,29 +891,30 @@ _bluez_cb_mouse_out(void *data, Evas *evas __UNUSED__, Evas_Object *obj __UNUSED
 }
 
 static void
-_bluez_edje_view_update(E_Bluez_Instance *inst, Evas_Object *o)
+_bluez_edje_view_update(E_Bluez_Instance *inst,
+                        Evas_Object      *o)
 {
    E_Bluez_Module_Context *ctxt = inst->ctxt;
    const char *name;
 
    if (!ctxt->has_manager)
      {
-	edje_object_part_text_set(o, "e.text.powered", "");
-	edje_object_part_text_set(o, "e.text.status", "");
-	edje_object_signal_emit(o, "e,changed,service,none", "e");
+        edje_object_part_text_set(o, "e.text.powered", "");
+        edje_object_part_text_set(o, "e.text.status", "");
+        edje_object_signal_emit(o, "e,changed,service,none", "e");
         edje_object_part_text_set(o, "e.text.name", _("No Bluetooth daemon"));
-	edje_object_signal_emit(o, "e,changed,name", "e");
-	return;
+        edje_object_signal_emit(o, "e,changed,name", "e");
+        return;
      }
 
    if (!inst->adapter)
      {
-	edje_object_part_text_set(o, "e.text.powered", "");
-	edje_object_part_text_set(o, "e.text.status", "");
-	edje_object_signal_emit(o, "e,changed,off", "e");
+        edje_object_part_text_set(o, "e.text.powered", "");
+        edje_object_part_text_set(o, "e.text.status", "");
+        edje_object_signal_emit(o, "e,changed,off", "e");
         edje_object_part_text_set(o, "e.text.name", _("No Bluetooth adapter"));
-	edje_object_signal_emit(o, "e,changed,name", "e");
-	return;
+        edje_object_signal_emit(o, "e,changed,name", "e");
+        return;
      }
 
    if (!e_bluez_adapter_name_get(inst->adapter, &name))
@@ -888,24 +924,24 @@ _bluez_edje_view_update(E_Bluez_Instance *inst, Evas_Object *o)
 
    if (inst->powered)
      {
-	if (inst->discoverable)
-	  {
-	     edje_object_signal_emit(o, "e,changed,powered", "e");
-	     edje_object_part_text_set
-	       (o, "e.text.status",
-		_("Bluetooth is powered and discoverable."));
-	  }
-	else
-	  {
-	     edje_object_signal_emit(o, "e,changed,hidden", "e");
-	     edje_object_part_text_set
-	       (o, "e.text.status", _("Bluetooth is powered and hidden."));
-	  }
+        if (inst->discoverable)
+          {
+             edje_object_signal_emit(o, "e,changed,powered", "e");
+             edje_object_part_text_set
+               (o, "e.text.status",
+               _("Bluetooth is powered and discoverable."));
+          }
+        else
+          {
+             edje_object_signal_emit(o, "e,changed,hidden", "e");
+             edje_object_part_text_set
+               (o, "e.text.status", _("Bluetooth is powered and hidden."));
+          }
      }
    else
      {
-	edje_object_signal_emit(o, "e,changed,off", "e");
-	edje_object_part_text_set(o, "e.text.status", _("Bluetooth is off."));
+        edje_object_signal_emit(o, "e,changed,off", "e");
+        edje_object_part_text_set(o, "e.text.status", _("Bluetooth is off."));
      }
 }
 
@@ -934,7 +970,10 @@ _bluez_gadget_update(E_Bluez_Instance *inst)
 /* Gadcon Api Functions */
 
 static E_Gadcon_Client *
-_gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
+_gc_init(E_Gadcon   *gc,
+         const char *name,
+         const char *id,
+         const char *style)
 {
    E_Bluez_Instance *inst;
    E_Bluez_Module_Context *ctxt;
@@ -969,16 +1008,16 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
 
    if (inst->adapter)
      {
-	Eina_Bool powered, discoverable, discovering;
+        Eina_Bool powered, discoverable, discovering;
 
-	if (e_bluez_adapter_powered_get(inst->adapter, &powered))
-	  inst->powered = powered;
+        if (e_bluez_adapter_powered_get(inst->adapter, &powered))
+          inst->powered = powered;
 
-	if (e_bluez_adapter_discoverable_get(inst->adapter, &discoverable))
-	  inst->discoverable = discoverable;
+        if (e_bluez_adapter_discoverable_get(inst->adapter, &discoverable))
+          inst->discoverable = discoverable;
 
-	if (e_bluez_adapter_discovering_get(inst->adapter, &discovering))
-	  inst->discovering = discovering;
+        if (e_bluez_adapter_discovering_get(inst->adapter, &discovering))
+          inst->discovering = discovering;
      }
 
    _bluez_gadget_update(inst);
@@ -1007,8 +1046,8 @@ _gc_shutdown(E_Gadcon_Client *gcc)
 
    if (inst->menu)
      {
-	e_menu_post_deactivate_callback_set(inst->menu, NULL, NULL);
-	e_object_del(E_OBJECT(inst->menu));
+        e_menu_post_deactivate_callback_set(inst->menu, NULL, NULL);
+        e_object_del(E_OBJECT(inst->menu));
      }
    evas_object_del(inst->ui.gadget);
 
@@ -1020,20 +1059,22 @@ _gc_shutdown(E_Gadcon_Client *gcc)
 }
 
 static void
-_gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient __UNUSED__)
+_gc_orient(E_Gadcon_Client       *gcc,
+           E_Gadcon_Orient orient __UNUSED__)
 {
    e_gadcon_client_aspect_set(gcc, 16, 16);
    e_gadcon_client_min_size_set(gcc, 16, 16);
 }
 
-static char *
+static const char *
 _gc_label(E_Gadcon_Client_Class *client_class __UNUSED__)
 {
    return _(_e_bluez_Name);
 }
 
 static Evas_Object *
-_gc_icon(E_Gadcon_Client_Class *client_class __UNUSED__, Evas *evas)
+_gc_icon(E_Gadcon_Client_Class *client_class __UNUSED__,
+         Evas                               *evas)
 {
    Evas_Object *o;
 
@@ -1055,19 +1096,19 @@ _gc_id_new(E_Gadcon_Client_Class *client_class __UNUSED__)
      return NULL;
 
    snprintf(tmpbuf, sizeof(tmpbuf), "bluez.%d",
-	    eina_list_count(ctxt->instances));
+            eina_list_count(ctxt->instances));
    return tmpbuf;
 }
 
 static const E_Gadcon_Client_Class _gc_class =
-  {
-    GADCON_CLIENT_CLASS_VERSION, _e_bluez_name,
-    {
+{
+   GADCON_CLIENT_CLASS_VERSION, _e_bluez_name,
+   {
       _gc_init, _gc_shutdown, _gc_orient, _gc_label, _gc_icon, _gc_id_new, NULL,
       e_gadcon_site_is_not_toolbar
-    },
-    E_GADCON_CLIENT_STYLE_PLAIN
-  };
+   },
+   E_GADCON_CLIENT_STYLE_PLAIN
+};
 
 EAPI E_Module_Api e_modapi = {E_MODULE_API_VERSION, _e_bluez_Name};
 
@@ -1080,11 +1121,11 @@ _bluez_actions_register(E_Bluez_Module_Context *ctxt)
    ctxt->actions.toggle_powered = e_action_add(_act_toggle_powered);
    if (ctxt->actions.toggle_powered)
      {
-	ctxt->actions.toggle_powered->func.go =
-	  _bluez_cb_toggle_powered;
-	e_action_predef_name_set
-	  (_(_e_bluez_Name), _(_lbl_toggle_powered), _act_toggle_powered,
-	   NULL, NULL, 0);
+        ctxt->actions.toggle_powered->func.go =
+          _bluez_cb_toggle_powered;
+        e_action_predef_name_set
+          (_(_e_bluez_Name), _(_lbl_toggle_powered), _act_toggle_powered,
+          NULL, NULL, 0);
      }
 }
 
@@ -1093,8 +1134,8 @@ _bluez_actions_unregister(E_Bluez_Module_Context *ctxt)
 {
    if (ctxt->actions.toggle_powered)
      {
-	e_action_predef_name_del(_(_e_bluez_Name), _(_lbl_toggle_powered));
-	e_action_del(_act_toggle_powered);
+        e_action_predef_name_del(_(_e_bluez_Name), _(_lbl_toggle_powered));
+        e_action_del(_act_toggle_powered);
      }
 }
 
@@ -1110,17 +1151,20 @@ _bluez_manager_changed_do(void *data)
 }
 
 static void
-_bluez_manager_changed(void *data, const E_Bluez_Element *element __UNUSED__)
+_bluez_manager_changed(void                          *data,
+                       const E_Bluez_Element *element __UNUSED__)
 {
    E_Bluez_Module_Context *ctxt = data;
    if (ctxt->poller.manager_changed)
      ecore_poller_del(ctxt->poller.manager_changed);
    ctxt->poller.manager_changed = ecore_poller_add
-     (ECORE_POLLER_CORE, 1, _bluez_manager_changed_do, ctxt);
+       (ECORE_POLLER_CORE, 1, _bluez_manager_changed_do, ctxt);
 }
 
 static void
-_properties_sync_callback(void *data, DBusMessage *msg __UNUSED__, DBusError *err)
+_properties_sync_callback(void            *data,
+                          DBusMessage *msg __UNUSED__,
+                          DBusError       *err)
 {
    E_Bluez_Instance *inst = data;
    Eina_Bool powered;
@@ -1128,29 +1172,31 @@ _properties_sync_callback(void *data, DBusMessage *msg __UNUSED__, DBusError *er
 
    if (err && dbus_error_is_set(err))
      {
-	dbus_error_free(err);
-	return;
+        dbus_error_free(err);
+        return;
      }
 
    if (!e_bluez_adapter_powered_get(inst->adapter, &powered))
      {
-	_bluez_operation_error_show(_("Query adapter's powered."));
-	return;
+        _bluez_operation_error_show(_("Query adapter's powered."));
+        return;
      }
 
    inst->powered = powered;
 
    if (!e_bluez_adapter_discoverable_get(inst->adapter, &discoverable))
      {
-	_bluez_operation_error_show(_("Query adapter's discoverable."));
-	return;
+        _bluez_operation_error_show(_("Query adapter's discoverable."));
+        return;
      }
 
    inst->discoverable = discoverable;
 }
 
 static void
-_default_adapter_callback(void *data, DBusMessage *msg, DBusError *err __UNUSED__)
+_default_adapter_callback(void          *data,
+                          DBusMessage   *msg,
+                          DBusError *err __UNUSED__)
 {
    E_Bluez_Module_Context *ctxt = data;
    const Eina_List *l;
@@ -1159,12 +1205,12 @@ _default_adapter_callback(void *data, DBusMessage *msg, DBusError *err __UNUSED_
 
    if (err && dbus_error_is_set(err))
      {
-	dbus_error_free(err);
-	return;
+        dbus_error_free(err);
+        return;
      }
 
    if (dbus_message_get_args(msg, NULL, DBUS_TYPE_OBJECT_PATH, &path,
-			     DBUS_TYPE_INVALID) == FALSE)
+                             DBUS_TYPE_INVALID) == FALSE)
      return;
 
    eina_stringshare_replace(&ctxt->default_adapter, path);
@@ -1173,18 +1219,22 @@ _default_adapter_callback(void *data, DBusMessage *msg, DBusError *err __UNUSED_
    // each instance. See the mixer module.
    EINA_LIST_FOREACH(ctxt->instances, l, inst)
      {
-	inst->adapter = e_bluez_adapter_get(path);
+        inst->adapter = e_bluez_adapter_get(path);
 
-	e_bluez_element_properties_sync_full
-	  (inst->adapter, _properties_sync_callback, inst);
+        e_bluez_element_properties_sync_full
+          (inst->adapter, _properties_sync_callback, inst);
      }
 }
 
 static Eina_Bool
-_bluez_event_manager_in(void *data, int type __UNUSED__, void *event __UNUSED__)
+_bluez_event_manager_in(void       *data,
+                        int type    __UNUSED__,
+                        void *event __UNUSED__)
 {
    E_Bluez_Module_Context *ctxt = data;
    E_Bluez_Element *element;
+   Eina_List *l;
+   E_Bluez_Instance *inst;
 
    ctxt->has_manager = EINA_TRUE;
 
@@ -1194,22 +1244,34 @@ _bluez_event_manager_in(void *data, int type __UNUSED__, void *event __UNUSED__)
 
    e_bluez_element_listener_add(element, _bluez_manager_changed, ctxt, NULL);
 
+   EINA_LIST_FOREACH(ctxt->instances, l, inst)
+     _bluez_gadget_update(inst);
+
    return ECORE_CALLBACK_PASS_ON;
 }
 
 static Eina_Bool
-_bluez_event_manager_out(void *data, int type __UNUSED__, void *event __UNUSED__)
+_bluez_event_manager_out(void       *data,
+                         int type    __UNUSED__,
+                         void *event __UNUSED__)
 {
    E_Bluez_Module_Context *ctxt = data;
+   E_Bluez_Instance *inst;
+   Eina_List *l;
 
    ctxt->has_manager = EINA_FALSE;
    eina_stringshare_replace(&ctxt->default_adapter, NULL);
 
+   EINA_LIST_FOREACH(ctxt->instances, l, inst)
+     _bluez_gadget_update(inst);
+
    return ECORE_CALLBACK_PASS_ON;
 }
 
 static Eina_Bool
-_bluez_event_element_updated(void *data, int type __UNUSED__, void *event __UNUSED__)
+_bluez_event_element_updated(void       *data,
+                             int type    __UNUSED__,
+                             void *event __UNUSED__)
 {
    E_Bluez_Module_Context *ctxt = data;
    E_Bluez_Element *element = event;
@@ -1230,12 +1292,12 @@ _bluez_event_element_updated(void *data, int type __UNUSED__, void *event __UNUS
 
    EINA_LIST_FOREACH(ctxt->instances, l, inst)
      {
-	if (inst->adapter != element) continue;
+        if (inst->adapter != element) continue;
 
-	inst->powered = powered;
-	inst->discoverable = discoverable;
-	inst->discovering = discovering;
-	_bluez_gadget_update(inst);
+        inst->powered = powered;
+        inst->discoverable = discoverable;
+        inst->discovering = discovering;
+        _bluez_gadget_update(inst);
      }
 
    return ECORE_CALLBACK_PASS_ON;
@@ -1245,13 +1307,13 @@ static void
 _bluez_events_register(E_Bluez_Module_Context *ctxt)
 {
    ctxt->event.manager_in = ecore_event_handler_add
-     (E_BLUEZ_EVENT_MANAGER_IN, _bluez_event_manager_in, ctxt);
+       (E_BLUEZ_EVENT_MANAGER_IN, _bluez_event_manager_in, ctxt);
    ctxt->event.manager_out = ecore_event_handler_add
-     (E_BLUEZ_EVENT_MANAGER_OUT, _bluez_event_manager_out, ctxt);
+       (E_BLUEZ_EVENT_MANAGER_OUT, _bluez_event_manager_out, ctxt);
    ctxt->event.element_updated = ecore_event_handler_add
-     (E_BLUEZ_EVENT_ELEMENT_UPDATED, _bluez_event_element_updated, ctxt);
+       (E_BLUEZ_EVENT_ELEMENT_UPDATED, _bluez_event_element_updated, ctxt);
    ctxt->event.device_found = ecore_event_handler_add
-     (E_BLUEZ_EVENT_DEVICE_FOUND, _bluez_event_devicefound, ctxt);
+       (E_BLUEZ_EVENT_DEVICE_FOUND, _bluez_event_devicefound, ctxt);
 
    // TODO: E_BLUEZ_EVENT_DEVICE_DISAPPEARED
 }
@@ -1319,12 +1381,12 @@ e_modapi_init(E_Module *m)
 
    if (_e_bluez_log_dom < 0)
      {
-	_e_bluez_log_dom = eina_log_domain_register("ebluez", EINA_COLOR_ORANGE);
-	if (_e_bluez_log_dom < 0)
-	  {
-	     //EINA_LOG_CRIT("could not register logging domain ebluez");
-	     goto error_log_domain;
-	  }
+        _e_bluez_log_dom = eina_log_domain_register("ebluez", EINA_COLOR_ORANGE);
+        if (_e_bluez_log_dom < 0)
+          {
+             //EINA_LOG_CRIT("could not register logging domain ebluez");
+               goto error_log_domain;
+          }
      }
 
    _bluez_agent_register(ctxt);
@@ -1335,11 +1397,11 @@ e_modapi_init(E_Module *m)
 
    return ctxt;
 
- error_log_domain:
+error_log_domain:
    _e_bluez_log_dom = -1;
    bluez_mod = NULL;
    e_bluez_system_shutdown();
- error_bluez_system_init:
+error_bluez_system_init:
    E_FREE(ctxt);
    return NULL;
 }
@@ -1350,10 +1412,10 @@ _bluez_instances_free(E_Bluez_Module_Context *ctxt)
    E_Bluez_Instance *inst;
    EINA_LIST_FREE(ctxt->instances, inst)
      {
-	if (inst->popup)
-	  _bluez_popup_del(inst);
-	if (inst->tip)
-	  _bluez_tip_del(inst);
+        if (inst->popup)
+          _bluez_popup_del(inst);
+        if (inst->tip)
+          _bluez_tip_del(inst);
 
         e_object_del(E_OBJECT(inst->gcc));
      }
@@ -1396,3 +1458,4 @@ e_modapi_save(E_Module *m __UNUSED__)
 {
    return 1;
 }
+
