@@ -201,8 +201,6 @@ _basic_apply_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
 
    EINA_LIST_FOREACH(cfdata->binding.edge, l, bi2)
      {
-	if (bi2->edge < 0) continue;
-
 	bi = E_NEW(E_Config_Binding_Edge, 1);
 	bi->context = bi2->context;
 	bi->edge = bi2->edge;
@@ -326,14 +324,14 @@ _fill_actions_list(E_Config_Dialog_Data *cfdata)
 
 	if (!actg->acts) continue;
 
-	e_widget_ilist_header_append(cfdata->gui.o_action_list, NULL, actg->act_grp);
+	e_widget_ilist_header_append(cfdata->gui.o_action_list, NULL, _(actg->act_grp));
 
 	for (l2 = actg->acts, a = 0; l2; l2 = l2->next, a++)
 	  {
 	     actd = l2->data;
 
 	     snprintf(buf, sizeof(buf), "%d %d", g, a);
-	     e_widget_ilist_append(cfdata->gui.o_action_list, NULL, actd->act_name,
+	     e_widget_ilist_append(cfdata->gui.o_action_list, NULL, _(actd->act_name),
 				   _action_change_cb, cfdata, buf);
 	  }
      }
@@ -1147,7 +1145,7 @@ _edge_grab_wnd_selection_apply(E_Config_Dialog_Data *cfdata)
 		  e_widget_disabled_set(cfdata->gui.o_params, 1);
 	       }
 	  }
-	else
+	else if (bi)
 	  {
 	     label = _edge_binding_text_get(bi->edge, bi->delay, bi->modifiers);
 	     e_widget_ilist_nth_label_set(cfdata->gui.o_binding_list, n, label);
@@ -1169,7 +1167,7 @@ _edge_grab_wnd_selection_apply(E_Config_Dialog_Data *cfdata)
 	actg = eina_list_nth(e_action_groups_get(), g);
 	if (actg) actd = eina_list_nth(actg->acts, a);
 
-	if (actd) label = actd->act_name;
+	if (actd) label = _(actd->act_name);
 
 	e_util_dialog_show(_("Binding Edge Error"), 
 			   _("The binding key sequence, that you choose,"
