@@ -26,7 +26,7 @@ e_int_config_window_maxpolicy(E_Container *con, const char *params __UNUSED__)
    E_Config_Dialog *cfd;
    E_Config_Dialog_View *v;
 
-   if (e_config_dialog_find("E", "_config_window_maxpolicy_dialog")) 
+   if (e_config_dialog_find("E", "windows/window_maxpolicy_dialog")) 
      return NULL;
    v = E_NEW(E_Config_Dialog_View, 1);
 
@@ -42,7 +42,7 @@ e_int_config_window_maxpolicy(E_Container *con, const char *params __UNUSED__)
 
    /* create config diaolg for NULL object/data */
    cfd = e_config_dialog_new(con, _("Window Maximize Policy"),
-			     "E", "_config_window_maxpolicy_dialog",
+			     "E", "windows/window_maxpolicy_dialog",
 			     "preferences-window-manipulation", 0, v, NULL);
    return cfd;
 }
