@@ -31,7 +31,7 @@ e_int_config_window_stacking(E_Container *con, const char *params __UNUSED__)
    E_Config_Dialog *cfd;
    E_Config_Dialog_View *v;
 
-   if (e_config_dialog_find("E", "_config_window_stacking_dialog")) 
+   if (e_config_dialog_find("E", "windows/window_stacking_dialog")) 
      return NULL;
    v = E_NEW(E_Config_Dialog_View, 1);
 
@@ -47,7 +47,7 @@ e_int_config_window_stacking(E_Container *con, const char *params __UNUSED__)
 
    /* create config diaolg for NULL object/data */
    cfd = e_config_dialog_new(con, _("Window Stacking"),
-			     "E", "_config_window_stacking_dialog",
+			     "E", "windows/window_stacking_dialog",
 			     "preferences-window-stacking", 0, v, NULL);
    return cfd;
 }
