@@ -13,7 +13,7 @@
 static E_Gadcon_Client *_gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style);
 static void _gc_shutdown(E_Gadcon_Client *gcc);
 static void _gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient);
-static char *_gc_label(E_Gadcon_Client_Class *client_class);
+static const char *_gc_label(E_Gadcon_Client_Class *client_class);
 static Evas_Object *_gc_icon(E_Gadcon_Client_Class *client_class, Evas *evas);
 static const char *_gc_id_new(E_Gadcon_Client_Class *client_class);
 static void _gc_id_del(E_Gadcon_Client_Class *client_class, const char *id);
@@ -115,8 +115,6 @@ static Eina_Bool  _ibar_cb_config_icons(void *data, int ev_type, void *ev);
 static E_Config_DD *conf_edd = NULL;
 static E_Config_DD *conf_item_edd = NULL;
 
-static int uuid = 0;
-
 Config *ibar_config = NULL;
 
 static E_Gadcon_Client *
@@ -207,7 +205,7 @@ _gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient)
    e_gadcon_client_min_size_set(gcc, 16, 16);
 }
 
-static char *
+static const char *
 _gc_label(E_Gadcon_Client_Class *client_class __UNUSED__)
 {
    return _("IBar");
@@ -300,25 +298,23 @@ _ibar_cb_empty_mouse_down(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNU
    b = data;
    if (!ibar_config->menu)
      {
-	E_Menu *ma, *mg;
+	E_Menu *m;
 	E_Menu_Item *mi;
 	int cx, cy, cw, ch;
 
-	ma = e_menu_new();
-	mg = e_menu_new();
-	e_menu_post_deactivate_callback_set(ma, _ibar_cb_menu_post, NULL);
-	ibar_config->menu = ma;
-
-	mi = e_menu_item_new(mg);
+	m = e_menu_new();
+	mi = e_menu_item_new(m);
 	e_menu_item_label_set(mi, _("Settings"));
 	e_util_menu_item_theme_icon_set(mi, "configure");
 	e_menu_item_callback_set(mi, _ibar_cb_menu_configuration, b);
 
-	e_gadcon_client_util_menu_items_append(b->inst->gcc, ma, mg, 0);
+	m = e_gadcon_client_util_menu_items_append(b->inst->gcc, m, 0);
+	e_menu_post_deactivate_callback_set(m, _ibar_cb_menu_post, NULL);
+	ibar_config->menu = m;
 
 	e_gadcon_canvas_zone_geometry_get(b->inst->gcc->gadcon,
 					  &cx, &cy, &cw, &ch);
-	e_menu_activate_mouse(ma,
+	e_menu_activate_mouse(m,
 			      e_util_zone_current_get(e_manager_current_get()),
 			      cx + ev->output.x, cy + ev->output.y, 1, 1,
 			      E_MENU_POP_DIRECTION_DOWN, ev->timestamp);
@@ -438,27 +434,9 @@ static Config_Item *
 _ibar_config_item_get(const char *id)
 {
    Config_Item *ci;
-   char buf[128];
 
-   if (!id)
-     {
-	snprintf(buf, sizeof(buf), "%s.%d", _gadcon_class.name, ++uuid);
-	id = buf;
-     }
-   else
-     {
-	const Eina_List *l;
+   GADCON_CLIENT_CONFIG_GET(Config_Item, ibar_config->items, _gadcon_class, id);
 
-	/* Find old config, or reuse supplied id */
-	EINA_LIST_FOREACH(ibar_config->items, l, ci)
-	  {
-	     if ((ci->id) && (!strcmp(ci->id, id)))
-	       {
-		  if (!ci->dir) ci->dir = eina_stringshare_add("default");
-		  return ci;
-	       }
-	  }
-     }
    ci = E_NEW(Config_Item, 1);
    ci->id = eina_stringshare_add(id);
    ci->dir = eina_stringshare_add("default");
@@ -776,18 +754,44 @@ _ibar_cb_icon_mouse_down(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUS
      }
    else if ((ev->button == 3) && (!ibar_config->menu))
      {
-	E_Menu *ma, *mg, *mo;
+	E_Menu *m, *mo;
 	E_Menu_Item *mi;
         char buf[256];
 	int cx, cy;
 
-	ma = e_menu_new();
-	e_menu_post_deactivate_callback_set(ma, _ibar_cb_menu_post, NULL);
-	ibar_config->menu = ma;
+	m = e_menu_new();
 
 	/* FIXME: other icon options go here too */
 	mo = e_menu_new();
 
+	if (e_configure_registry_exists("applications/new_application")) 
+	  {
+	     mi = e_menu_item_new(m);
+	     e_menu_item_label_set(mi, _("Create new Icon"));
+	     e_util_menu_item_theme_icon_set(mi, "document-new");
+	     e_menu_item_callback_set(mi, _ibar_cb_menu_icon_new, NULL);
+
+             mi = e_menu_item_new(m);
+             e_menu_item_separator_set(mi, 1);
+	  }
+
+	if (e_configure_registry_exists("applications/ibar_applications")) 
+	  {
+	     mi = e_menu_item_new(m);
+	     e_menu_item_label_set(mi, _("Contents"));
+	     e_util_menu_item_theme_icon_set(mi, "list-add");
+	     e_menu_item_callback_set(mi, _ibar_cb_menu_icon_add, NULL);
+	  }
+
+	mi = e_menu_item_new(m);
+	e_menu_item_label_set(mi, _("Settings"));
+	e_util_menu_item_theme_icon_set(mi, "configure");
+	e_menu_item_callback_set(mi, _ibar_cb_menu_configuration, ic->ibar);
+
+	m = e_gadcon_client_util_menu_items_append(ic->ibar->inst->gcc, m, 0);
+	e_menu_post_deactivate_callback_set(m, _ibar_cb_menu_post, NULL);
+	ibar_config->menu = m;
+
 	mi = e_menu_item_new(mo);
 	e_menu_item_label_set(mi, _("Properties"));
 	e_util_menu_item_theme_icon_set(mi, "configure");
@@ -798,7 +802,7 @@ _ibar_cb_icon_mouse_down(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUS
 	e_util_menu_item_theme_icon_set(mi, "list-remove");
 	e_menu_item_callback_set(mi, _ibar_cb_menu_icon_remove, ic);
 
-        mi = e_menu_item_new(ma);
+        mi = e_menu_item_new_relative(m, NULL);
         snprintf(buf, sizeof(buf), "Icon %s", ic->app->name);
         e_menu_item_label_set(mi, _(buf));
         e_util_desktop_menu_item_icon_add(ic->app, 
@@ -806,35 +810,9 @@ _ibar_cb_icon_mouse_down(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUS
                                           mi);
         e_menu_item_submenu_set(mi, mo);
 
-	mg = e_menu_new();
-	if (e_configure_registry_exists("applications/new_application")) 
-	  {
-	     mi = e_menu_item_new(mg);
-	     e_menu_item_label_set(mi, _("Create new Icon"));
-	     e_util_menu_item_theme_icon_set(mi, "document-new");
-	     e_menu_item_callback_set(mi, _ibar_cb_menu_icon_new, NULL);
-
-             mi = e_menu_item_new(mg);
-             e_menu_item_separator_set(mi, 1);
-	  }
-
-	if (e_configure_registry_exists("applications/ibar_applications")) 
-	  {
-	     mi = e_menu_item_new(mg);
-	     e_menu_item_label_set(mi, _("Contents"));
-	     e_util_menu_item_theme_icon_set(mi, "list-add");
-	     e_menu_item_callback_set(mi, _ibar_cb_menu_icon_add, NULL);
-	  }
-
-	mi = e_menu_item_new(mg);
-	e_menu_item_label_set(mi, _("Settings"));
-	e_util_menu_item_theme_icon_set(mi, "configure");
-	e_menu_item_callback_set(mi, _ibar_cb_menu_configuration, ic->ibar);
-
-	e_gadcon_client_util_menu_items_append(ic->ibar->inst->gcc, ma, mg, 0);
 	e_gadcon_canvas_zone_geometry_get(ic->ibar->inst->gcc->gadcon,
 					  &cx, &cy, NULL, NULL);
-	e_menu_activate_mouse(ma,
+	e_menu_activate_mouse(m,
 			      e_util_zone_current_get(e_manager_current_get()),
 			      cx + ev->output.x, cy + ev->output.y, 1, 1,
 			      E_MENU_POP_DIRECTION_DOWN, ev->timestamp);
@@ -1207,57 +1185,6 @@ e_modapi_init(E_Module *m)
 	ci->eap_label = 0;
 	ibar_config->items = eina_list_append(ibar_config->items, ci);
      }
-   else
-     {
-	Eina_List *removes = NULL;
-	const Eina_List *l;
-	Config_Item *ci;
-
-	EINA_LIST_FOREACH(ibar_config->items, l, ci)
-	  {
-	     if (!ci->id)
-	       removes = eina_list_append(removes, ci);
-	     else if (!ci->dir)
-	       removes = eina_list_append(removes, ci);
-	     else
-	       {
-		  const Eina_List *ll;
-		  Config_Item *ci2;
-
-		  EINA_LIST_FOREACH(l->next, ll, ci2)
-		    {
-		       if ((ci2->id) && (!strcmp(ci->id, ci2->id)))
-			 {
-			    removes = eina_list_append(removes, ci);
-			    break;
-			 }
-		    }
-	       }
-	  }
-	EINA_LIST_FREE(removes, ci)
-	  {
-	     ibar_config->items = eina_list_remove(ibar_config->items, ci);
-	     if (ci->id) eina_stringshare_del(ci->id);
-	     if (ci->dir) eina_stringshare_del(ci->dir);
-	     E_FREE(ci);
-          }
-	EINA_LIST_FOREACH(ibar_config->items, l, ci)
-          {
-	     if (ci->id)
-	       {
-		  const char *p;
-
-		  p = strrchr(ci->id, '.');
-		  if (p)
-		    {
-		       int id;
-
-		       id = atoi(p + 1);
-		       if (id > uuid) uuid = id;
-		    }
-	       }
-	  }
-     }
  
    ibar_config->module = m;
 
