@@ -1,6 +1,10 @@
 #ifndef E_MOD_MAIN_H
 # define E_MOD_MAIN_H
 
+# ifdef HAVE_ENOTIFY
+#  include <E_Notification_Daemon.h>
+# endif
+
 EAPI extern E_Module_Api e_modapi;
 
 EAPI void *e_modapi_init(E_Module *m);
