@@ -14,7 +14,7 @@ struct _Instance
 static E_Gadcon_Client *_gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style);
 static void _gc_shutdown(E_Gadcon_Client *gcc);
 static void _gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient);
-static char *_gc_label(E_Gadcon_Client_Class *cc);
+static const char *_gc_label(E_Gadcon_Client_Class *cc);
 static Evas_Object *_gc_icon(E_Gadcon_Client_Class *cc, Evas *evas);
 static const char *_gc_id_new(E_Gadcon_Client_Class *cc);
 static void _cb_action_mode_single(void *data, Evas_Object *obj __UNUSED__, const char *emission __UNUSED__, const char *source __UNUSED__);
@@ -71,18 +71,18 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
    inst = E_NEW(Instance, 1);
    inst->o_toggle = edje_object_add(gc->evas);
    e_theme_edje_object_set(inst->o_toggle, 
-			   "base/theme/modules/illume_mode_toggle",
-			   "e/modules/illume_mode_toggle/main");
+                           "base/theme/modules/illume_mode_toggle",
+                           "e/modules/illume_mode_toggle/main");
 
    inst->gcc = e_gadcon_client_new(gc, name, id, style, inst->o_toggle);
    inst->gcc->data = inst;
 
    edje_object_signal_callback_add(inst->o_toggle, "e,action,mode,single", "",
-				   _cb_action_mode_single, inst);
+                                   _cb_action_mode_single, inst);
    edje_object_signal_callback_add(inst->o_toggle, "e,action,mode,dual,top", "",
-				   _cb_action_mode_dual_top, inst);
+                                   _cb_action_mode_dual_top, inst);
    edje_object_signal_callback_add(inst->o_toggle, "e,action,mode,dual,left", "",
-				   _cb_action_mode_dual_left, inst);
+                                   _cb_action_mode_dual_left, inst);
 
    _set_icon(inst);
 
@@ -113,7 +113,7 @@ _gc_orient(E_Gadcon_Client *gcc, E_Gadcon_Orient orient __UNUSED__)
    e_gadcon_client_min_size_set(gcc, 16, 16);
 }
 
-static char *
+static const char *
 _gc_label(E_Gadcon_Client_Class *cc __UNUSED__) 
 {
    return _("Illume-Mode-Toggle");
