@@ -2,6 +2,9 @@
 #include "e_mod_config.h"
 
 /**
+ * @addtogroup Module_Illume2
+ * @{
+ *
  * @defgroup E_Illume_Main_Group Illume API Information
  * 
  * The following group defines variables, structures, and functions available 
@@ -299,9 +302,10 @@ e_illume_border_is_splash(E_Border *bd)
    /* check for transient flag */
 //   if (bd->client.icccm.transient_for != 0) return EINA_TRUE;
 
-   /* NB: may or may not need to handle these. Needs Testing */
+   /* NB: may or may not need to handle these. Needs Testing
    if (bd->client.netwm.extra_types) 
      printf("\t\tBorder has extra types: %s\n", bd->client.icccm.class);
+   */
 
    /* return a fallback */
    return EINA_FALSE;
@@ -334,9 +338,10 @@ e_illume_border_is_dialog(E_Border *bd)
     * not a dialog. */
 //   if (bd->client.icccm.client_leader) return EINA_TRUE;
 
-   /* NB: may or may not need to handle these. Needs Testing */
+   /* NB: may or may not need to handle these. Needs Testing
    if (bd->client.netwm.extra_types) 
      printf("\t\tBorder has extra types: %s\n", bd->client.icccm.class);
+   */
 
    /* return a fallback */
    return EINA_FALSE;
@@ -430,6 +435,35 @@ e_illume_border_is_quickpanel(E_Border *bd)
    return bd->client.illume.quickpanel.quickpanel;
 }
 
+/**
+ * Determine if the border request a fixed size.
+ * 
+ * @param bd The border to get the minium space for.
+ * @return EINA_TRUE if border requested fixed size, EINA_FALSE otherwise.
+ *
+ * @note If @p bd is NULL then this function will return EINA_FALSE.
+ *
+ * @ingroup E_Illume_Main_Group
+ */
+EAPI Eina_Bool 
+e_illume_border_is_fixed_size(E_Border *bd)
+{
+   /* make sure we have a border */
+   if (!bd) return EINA_FALSE;
+
+   if ((bd->client.icccm.min_w == bd->client.icccm.max_w) &&
+       (bd->client.icccm.min_h == bd->client.icccm.max_h))
+     return EINA_TRUE;
+   
+   if ((bd->client.mwm.exists) && 
+       !((bd->client.mwm.func & ECORE_X_MWM_HINT_FUNC_ALL) ||
+         (bd->client.mwm.func & ECORE_X_MWM_HINT_FUNC_MAXIMIZE) ||
+         (bd->client.mwm.func & ECORE_X_MWM_HINT_FUNC_RESIZE)))
+     return EINA_TRUE;
+
+   return EINA_FALSE;
+}
+
 /**
  * Retrieves the minimum space required to display this border.
  * 
@@ -973,3 +1007,7 @@ e_illume_quickpanel_hide(E_Zone *zone)
    ecore_x_e_illume_quickpanel_state_send(zone->black_win, 
                                           ECORE_X_ILLUME_QUICKPANEL_STATE_OFF);
 }
+
+/**
+ * @}
+ */
