@@ -7,7 +7,13 @@
 int e_winlist_init(void);
 int e_winlist_shutdown(void);
 
-int  e_winlist_show(E_Zone *zone, Eina_Bool same_class);
+typedef enum _E_Winlist_Filter {
+  E_WINLIST_FILTER_NONE = 0,
+  E_WINLIST_FILTER_CLASS_WINDOWS = 1, /* all windows from the same class */
+  E_WINLIST_FILTER_CLASSES = 2 /* loop through classes (last selected win) */
+} E_Winlist_Filter;
+
+int  e_winlist_show(E_Zone *zone, E_Winlist_Filter filter);
 void e_winlist_hide(void);
 void e_winlist_next(void);
 void e_winlist_prev(void);
